<?php
require_once("cwfUI.inc.php");

class DbAdminUI extends cwfUI {
  protected static $accessRight = "edit_admins";
  protected static $dataClass = "DbAdmin";
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct() {
    parent::__construct();
    $this->initialize();
  }
  
  protected function initialize() {
    parent::initialize();
    $this->title = _("Admins");
    $this->header = "  <script type=\"text/javascript\" src=\"".CWF_HTTP_PATH."cwf/js/cwfToggle.js\"></script>\n";
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // security
  private function adminHasAccessRight($accessRight) {
    return (($_SESSION['admin']['login']=="root" || in_array($accessRight, $_SESSION['admin']['access_rights'])) ? "" : " disabled");
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  static public function getValidationRules() {
    $rules = array(
        "login"=>array("required"=>true),
        "passwd_repeat"=>array("equalTo"=>"#passwd"),
        "email"=>array("email"=>true)
      );
    $messages = array(
        "login"=>_("Please enter a login name."),
        "passwd_repeat"=>array("equalTo"=>_("Passwords do not match.")),
        "email"=>_("Email address is not valid.")
      );
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }
  
  public function getData($asArray=true) {
    if(!$asArray) {
      $data = clone $this->data;
      return $data;
    }
    
    $array = $this->data->toArray();
    $array['generate_passwd'] = 0;
    return $array;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // Database operations
  static public function readList($DB) {
    if($_SESSION['admin']['login']=='root')
      return DbAdmin::readList($DB);
    else
      return DbAdmin::readList($DB, "db_admin_group_ids RLIKE '(^$)|((^|,)(".implode("|", $_SESSION['admin']['db_admin_group_ids']).")(,|$))' AND login<>'root'");
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<div class="form_controls_top">
<p>
  <input type="submit" id="kdb_save" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('<?=get_class()?>', 'save'); return false;">
  <input type="submit" id="kdb_save_as" name="kdb_save_as" value="<?=_("Save as new")?>" onClick="kdbSaveEntry('<?=get_class()?>', 'saveasnew'); return false;">
  <input type="submit" id="kdb_delete" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbDeleteEntry('<?=get_class()?>'); return false;">
  <select id="admin_list" name="admin_list" class="select_id" onChange="kdbUpdateForm(this, '<?=get_class()?>');">
    <option value="-1"><?= _("Choose admin") ?></option>
<?php
    $admins = static::readList($DB);
    foreach ($admins as $admin)
      echo "    <option value=\"{$admin['id']}\">{$admin['name']}</option>\n";
?>
  </select>
</p>
</div>

<h3 class="first"><?=_("Admin profile")?></h3>

<input type="hidden" id="db_admin_id" name="db_admin_id" class="id" value="<?= $this->data->db_admin_id ?>">

<p>
  <label for="login" class="required"><?=_("User name")?>:</label>
  <input type="text" id="login" name="login" value="<?=$this->data->login?>" class="required">
</p>

<p>
  <label for="admin_name"><?=_("Full name")?>:</label>
  <input type="text" id="admin_name" name="admin_name" value="<?=$this->data->admin_name?>">
</p>

<p>
  <label for="email"><?=_("Email address")?>:</label>
  <input type="text" id="email" name="email" value="<?=$this->data->email?>">
    <span id="tt_email" class="tooltip"><?=_("The email address is only used interally, e.g. to send the initial password.")?></span>
</p>

<p>
  <label for="passwd"><?=_("Password")?>:</label>
  <input type="password" id="passwd" name="passwd" value="">
  <input type="checkbox" id="generate_passwd" name="generate_passwd" value="1">
    <span id="tt_generate_passwd" class="tooltip"><?=_("Generate password")?></span>
</p>

<p>
  <label for="passwd"><?=_("Repeat password")?>:</label>
  <input type="password" id="passwd_repeat" name="passwd_repeat" value="">
</p>

<p>
  <label for="ip_addresses"><?=_("IP address(es)")?>:</label>
  <input type="text" id="ip_addresses" name="ip_addresses" value="<?=$this->data->ip_addresses?>">
    <span id="tt_ip_addresses" class="tooltip"><?= _("Space separated list of allowed ip addresses. Whole subnets are unblocked via 12.12.12.0/24, 12.12.0.0/16, etc.") ?></span>
</p>

<div class="toggle with_tooltip" id="db_admin_group_ids">
  <div class="toggle_part toggle_available">
    <div><?=_("Groups")?>:</div>
    <ul>
<?php
    $groupCounter = 0;
    $groupNames = array();
    foreach (DbAdminGroup::readList($DB) as $group) {
      if($_SESSION['admin']['login']=="root" || in_array($group['id'], $_SESSION['admin']['db_admin_group_ids'])) {
        if (!in_array($group['id'], $this->data->db_admin_group_ids))
          echo "      <li name=\"toggle_{$groupCounter}\">{$group['name']}<input type=\"hidden\" name=\"db_admin_group_ids[]\" value=\"{$group['id']}\" disabled></li>\n";
        else
          $groupNames[$groupCounter] = $group;
        $groupCounter++;
      }
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_add">&raquo;</span><br><span class="toggle_remove">&laquo;</span></div>
  <div class="toggle_part toggle_selected toggle_sorted">
    <div><?=_("Selected groups")?>:</div>
    <ul>
<?php
    foreach ($groupNames as $groupCounter => $group) {
      echo "      <li name=\"toggle_{$groupCounter}\">{$group['name']}<input type=\"hidden\" name=\"db_admin_group_ids[]\" value=\"{$group['id']}\"></li>\n";
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_up">&uArr;</span><br><span class="toggle_down">&dArr;</span></div>
</div>
  <span id="tt_db_admin_group_ids" class="tooltip"><?=_("The admin can only edit events of the selected groups.")?></span>


<h3><?=_("Access rights")?></h3>
<div class="toggle" id="access_rights">
  <div class="toggle_part toggle_available">
    <div><?=_("Actions")?>:</div>
    <ul>
<?php
    $accessCounter = 0;
    $accessNames = array();
    foreach (DbAdmin::getAccessRights() as $name => $text) {
      if($this->adminHasAccessRight($name)=="") {
        if (!in_array($name, $this->data->access_rights))
          echo "      <li id=\"{$name}\" name=\"toggle_{$accessCounter}\">{$text}<input type=\"hidden\" name=\"access_rights[]\" value=\"{$name}\" disabled></li>\n";
        else
          $accessNames[$accessCounter] = $name;
        $accessCounter++;
      }
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_add">&raquo;</span><br><span class="toggle_remove">&laquo;</span></div>
  <div class="toggle_part toggle_selected toggle_sorted">
    <div><?=_("Selected actions")?>:</div>
    <ul>
<?php
    foreach ($accessNames as $accessCounter => $name) {
      echo "      <li id=\"{$name}\" name=\"toggle_{$accessCounter}\">".DbAdmin::getAccessRights($name)."<input type=\"hidden\" name=\"access_rights[]\" value=\"{$name}\"></li>\n";
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_up">&uArr;</span><br><span class="toggle_down">&dArr;</span></div>
</div>


<span id="tt_kdb_options" class="tooltip"><?=_("The admin is allowed to change the K_Db options.")?></span>
<span id="tt_edit_event" class="tooltip"><?=_("The admin is allowed to add, edit and delete events.")?></span>
<span id="tt_edit_fees" class="tooltip"><?=_("The admin is allowed to add, edit and delete event fees (i. e. change the event form).")?></span>
<span id="tt_edit_payment" class="tooltip"><?=_("The admin is allowed to add, edit and delete payment types.")?></span>
<span id="tt_edit_disclaimers" class="tooltip"><?=_("The admin is allowed to add, edit and delete disclaimers.")?></span>
<span id="tt_edit_salutations" class="tooltip"><?=_("The admin is allowed to add, edit and delete salutations.")?></span>
<span id="tt_edit_topics" class="tooltip"><?=_("The admin is allowed to add, edit and delete topics.")?></span>
<span id="tt_edit_views" class="tooltip"><?=_("The admin is allowed to add, edit and delete views.")?></span>
<span id="tt_edit_admins" class="tooltip"><?=_("The admin is allowed to add, edit and delete admin accounts.")?></span>
<span id="tt_edit_admingroups" class="tooltip"><?=_("The admin is allowed to add, edit and delete admin groups.")?></span>

<br style="clear:both;">

<h3><?=_("Miscellaneous")?></h3>

<p>
  <label for="first_login"><?=_("Enforce password change")?>:</label>
  <input type="checkbox" id="first_login" name="first_login" value="1"<?=(($this->data->first_login) ? " checked" : "")?>>
    <span id="tt_first_login" class="tooltip"><?=_("Enforce password change on next login.")?></span>
</p>

<p>
  <label for="send_email"><?=_("Send email")?>:</label>
  <input type="checkbox" id="send_email" name="send_email" value="1">
    <span id="tt_send_email" class="tooltip"><?=_("Send email with login details to the provided email address.")?></span>
</p>

<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_save2" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('<?=get_class()?>', 'save'); return false;">
  <input type="submit" id="kdb_save_as2" name="kdb_save_as" value="<?=_("Save as new")?>" onClick="kdbSaveEntry('<?=get_class()?>', 'saveasnew'); return false;">
  <input type="submit" id="kdb_delete2" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbDeleteEntry('<?=get_class()?>'); return false;">
</p>
</div>
</form>
<?php
  }
}

?>