<?php 
require_once("icwfData.inc.php");
require_once("FormValidation.inc.php");

class KDbOptions implements icwfData {
  private static $noExport = array();
  private static $notInArray = array("validation");
  private $validation;
  
  private $organisation_name;
  private $root_email;
  private $allow_user_login;
  private $disable_file_upload;
  private $enable_multiple_registration;
  private $email_duplicates;
  private $css_skin;
  private $force_language;
  private $db_host;
  private $db_name;
  private $db_user;
  private $db_passwd;
  private $admin_login_mode;
  private $currency;
  private $user_properties;
  private $user_properties_req;
  private $confirmation_text;
  private $confirmation_email;
  private $returnpath_workaround;
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  private function initialize() {
    foreach ($this as $key => $value)
      if(in_array($key, array("user_properties", "user_properties_req")))
        $this->$key = array();
      else
        $this->$key = null;
  }
  
  public function __construct(FormValidation $validation=null) {
    $this->initialize();
    
    if(!defined("THIS_FILE") || THIS_FILE!="setup.php")
      $this->readData();
    
    $this->validation = $validation;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // get values
  public function __get($name) {
    if (array_key_exists($name, get_class_vars(get_class())) && !in_array($name, self::$noExport))
      return $this->$name;
    return null;
  }

  public function getIDName() {
    return "";
  }
  
  public function toArray() {
    $array = array();
    foreach ($this as $key => $value)
      if(!in_array($key, self::$notInArray))
        $array[$key] = $value; 
    return $array;
  }
  
  public function getPostBackData() {
    return array();
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////////
  // set values
  public function setValidation(FormValidation $validation) {
    $this->validation = $validation;
  }
  
  private function checkConnection() {
    $checkDb = new DbConnection($this->db_host, $this->db_user, $this->db_passwd, $this->db_name);
    if ($checkDb->getConnectionError()) {
      $this->validation->addInvalidField("db_connection", _("Database connection failed."));
      return 0;
    }

    return 1;
  }
  
  public function fromArray($array) {
    foreach ($this as $key => $value) {
      switch ($key) {
        case "validation":
          break;
          
        case "allow_user_login":
        case "disable_file_upload":
        case "enable_multiple_registration":
        case "returnpath_workaround":
          $this->$key = ((isset($array[$key]) && $array[$key]) ? 1 : 0);
          break;
        case "email_duplicates":
          if(isset($array[$key]) && 
             in_array($array[$key], array(EMAIL_DONT_CHECK, EMAIL_CHECK_EVENT, EMAIL_ALWAYS_CHECK)))
            $this->$key = $array[$key];
          else
            $this->$key = null;
          break;
        case "admin_login_mode":
          if(isset($array[$key]) && 
             in_array($array[$key], array(LOGIN_MODE_IP, LOGIN_MODE_PASSWD, LOGIN_MODE_IP_OR_PW, LOGIN_MODE_IP_AND_PW)))
            $this->$key = $array[$key];
          else
            $this->$key = null;
          break;
          
        default:
          if(isset($array[$key]))
            $this->$key = $array[$key];
          else if(in_array($key, array("user_properties", "user_properties_req")))
            $this->$key = array();
          else
            $this->$key = null;
          break;
      }
    }
    
    $array['db_connection'] = 1;
    return ($this->checkConnection() && $this->validation->validate($array));
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - read
  private function getConstValue($name) {
    return (defined($name) ? constant($name) : "");
  }
  public function readData(DbConnection $DB=null, $conditions="") {
    $this->organisation_name = $this->getConstValue("ORGANISATION_NAME");
    $this->root_email = $this->getConstValue("ROOT_EMAIL");
    $this->allow_user_login = $this->getConstValue("ALLOW_USER_LOGIN");
    $this->disable_file_upload = $this->getConstValue("DISABLE_FILE_UPLOAD");
    $this->enable_multiple_registration = $this->getConstValue("ENABLE_MULTIPLE_REGISTRATION");
    $this->email_duplicates = $this->getConstValue("EMAIL_DUPLICATES");
    $this->css_skin = $this->getConstValue("CSS_SKIN");
    $this->force_language = ($this->getConstValue("USE_LANG") ? "" : $this->getConstValue("DEFAULT_LANG"));
    $this->db_host = $this->getConstValue("DB_HOST");
    $this->db_name = $this->getConstValue("DB_NAME");
    $this->db_user = $this->getConstValue("DB_USER");
    $this->db_passwd = $this->getConstValue("DB_PASSWD");
    $this->admin_login_mode = $this->getConstValue("ADMIN_LOGIN_MODE");
    $this->currency = $this->getConstValue("CURRENCY");
    $this->user_properties = explode(",", $this->getConstValue("USER_PROPERTIES"));
    $this->user_properties_req = explode(",", $this->getConstValue("USER_PROPERTIES_REQ"));
    $this->confirmation_text = $this->getConstValue("KDB_CONFIRMATION_TEXT");
    $this->confirmation_email = $this->getConstValue("KDB_CONFIRMATION_EMAIL");
    $this->returnpath_workaround = $this->getConstValue("RETURNPATH_WORKAROUND");
    
    return array(0, "");
  }
  
  static public function readList(DbConnection $DB) {
    return array();
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - write
  public function writeData(DbConnection $DB) {
    $configFile = CWF_PATH."config/config.inc.php";
    if(file_exists($configFile) && !is_writable($configFile))
      return array(1, _("Config file '{$configFile}' is readonly."));
    
    $useLang = ($this->force_language=="" ? 1 : 0);
    $forceLang = ($this->force_language=="" ? "de" : $this->force_language);
    $cwf_path = rtrim(dirname(dirname($_SERVER['SCRIPT_FILENAME'])), '/').'/';
    $cwf_http_path = rtrim(dirname(dirname(preg_replace('~\.php/.*~', '.php', $_SERVER['PHP_SELF']))), '/').'/';
    $user_properties = implode(",", $this->user_properties);
    $user_properties_req = implode(",", $this->user_properties_req);
    $data = <<<EOD
<?php
// CWF options
define("CWF_PATH", '{$cwf_path}');
define("CWF_HTTP_PATH", '{$cwf_http_path}'); 
ini_set("include_path", CWF_PATH."cwf".PATH_SEPARATOR.CWF_PATH."k_db".PATH_SEPARATOR.CWF_PATH."admin");
define("AUTOLOADER_SRC", 'cwf/'.PATH_SEPARATOR.'k_db/'.PATH_SEPARATOR.'admin/');
define("USE_LANG", {$useLang});
define('DEFAULT_LANG', '{$forceLang}');

define("ORGANISATION_NAME", '{$this->organisation_name}');
define("ROOT_EMAIL", '{$this->root_email}');
define("ALLOW_USER_LOGIN", '{$this->allow_user_login}');
define("DISABLE_FILE_UPLOAD", '{$this->disable_file_upload}');
define("ENABLE_MULTIPLE_REGISTRATION", '{$this->enable_multiple_registration}');
define("EMAIL_DUPLICATES", '{$this->email_duplicates}');
define("CSS_SKIN", '{$this->css_skin}');
define("CURRENCY", '{$this->currency}');

define("RETURNPATH_WORKAROUND", '{$this->returnpath_workaround}');

//Database settings
define("DB_HOST", '{$this->db_host}');
define("DB_NAME", '{$this->db_name}');
define("DB_USER", '{$this->db_user}');
define("DB_PASSWD", '{$this->db_passwd}');     
     
//Security settings
define("ADMIN_LOGIN_MODE", '{$this->admin_login_mode}');

//User properties
define("USER_PROPERTIES", '{$user_properties}');
define("USER_PROPERTIES_REQ", '{$user_properties_req}');

//Registration confirmation
define("KDB_CONFIRMATION_TEXT", '{$this->confirmation_text}');
define("KDB_CONFIRMATION_EMAIL", '{$this->confirmation_email}');
?>
EOD;

    file_put_contents($configFile, $data);
    return array(0, "");
  }

  static public function deleteData(DbConnection $DB, $id) {
    return array(0, "");
  }
}
?>