<?php
require_once("cwfUI.inc.php");

class ViewUI extends cwfUI {
  protected static $accessRight = "edit_views";
  protected static $dataClass = "View";
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct() {
    parent::__construct();
    $this->initialize();
  }
  
  protected function initialize() {
    parent::initialize();
    $this->title = _("Views");
    $this->header .= "  <script type=\"text/javascript\" src=\"".CWF_HTTP_PATH."cwf/js/cwfToggle.js\"></script>\n";
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  public function getPostBackXML(DbConnection $DB, $action) {
    $xml = parent::getPostBackXML($DB, $action);
    switch ($action) {
      case "saveasnew":
      case "save":
      case "delete":
        $menu = new MainAdminUI($DB);
        $xml .= "  <replaceHTMLElement id=\"#menu ul#dropdownmenu li#menuitem_Views.submenu ul\"><![CDATA[\n";
        $xml .= "<ul>\n";
        $dataClass = static::$dataClass;
        $xml .= $menu->getMenuPublic("Create_edit_Views", $dataClass::getMenuArray());
        $xml .= "</ul>\n";
        $xml .= "]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        break;
    }
    return $xml;
  }
  
  static public function getValidationRules() {
    $rules = array(
        "view_name"=>array("required"=>true)
      );
    $messages = array(
        "view_name"=>_("You have to supply a name for the view.")
      );
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<div class="form_controls_top">
<p>
  <input type="submit" id="kdb_save" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('ViewUI', 'save'); return false;">
  <input type="submit" id="kdb_save_as" name="kdb_save_as" value="<?=_("Save as new")?>" onClick="kdbSaveEntry('ViewUI', 'saveasnew'); return false;">
  <input type="submit" id="kdb_delete" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbDeleteEntry('ViewUI'); return false;">
  <select id="view_list" name="view_list" class="select_id" onChange="kdbUpdateForm(this, 'ViewUI');">
    <option value="-1"><?= _("Choose view") ?></option>
<?php
    $views = static::readList($DB);
    foreach ($views as $view)
      echo "    <option value=\"{$view['id']}\">{$view['name']}</option>\n";
?>
  </select>
</p>
</div>

<h3 class="first"><?=_("Views")?></h3>

<input type="hidden" id="view_id" name="view_id" class="id" value="<?= $this->data->view_id ?>">

<p>
  <label for="view_name" class="required"><?=_("View name")?>:</label>
  <input type="text" id="view_name" name="view_name" value="<?=$this->data->view_name?>" class="required">
</p>

<p>
  <label for="edit_booking_check"><?=_("Booking checks editable")?>:</label>
  <input type="checkbox" id="edit_booking_check" name="edit_booking_check" value="1"<?=(($this->data->edit_booking_check) ? " checked" : "")?>>
    <span id="tt_edit_booking_check" class="tooltip"><?=_("If checked booking comments can be added and changed.")?></span>
</p>

<p>
  <label for="edit_user_data"><?=_("User data editable")?>:</label>
  <input type="checkbox" id="edit_user_data" name="edit_user_data" value="1"<?=(($this->data->edit_user_data) ? " checked" : "")?>>
    <span id="tt_edit_user_data" class="tooltip"><?=_("If checked user and booking data can be changed in this view.")?></span>
</p>

<p>
  <label for="sort_column"><?=_("Sort by")?>:</label>
  <select id="sort_column" name="sort_column">
    <option value="-1"><?= _("Choose column") ?></option>
<?php
    $bookingProperties = array(
      "booking_date"=>_("Booking date"),
      "booked_options"=>_("Booked options"),
      "grandtotal"=>_("Grand total")
    );
    $pluginColumns = Plugins::addViewColumns($this->data->columns, $propertyId, $propertyCounter);
    
    foreach (User::getProperties() as $property => $name)
      echo "    <option value=\"$property\"".($this->data->sort_column==$property ? " selected" : "").">{$name}</option>\n";
    foreach ($bookingProperties as $property => $name)
      echo "    <option value=\"$property\"".($this->data->sort_column==$property ? " selected" : "").">{$name}</option>\n";
    foreach (UserBookingCheck::getProperties() as $property => $name)
      echo "    <option value=\"$property\"".($this->data->sort_column==$property ? " selected" : "").">{$name}</option>\n";
    foreach ($pluginColumns as $newColumn)
      echo "    <option value=\"{$newColumn['property']}\"".($this->data->sort_column==$newColumn['property'] ? " selected" : "").">{$newColumn['name']}</option>\n";
?>
  </select>
  <input type="checkbox" id="sort_desc" name="sort_desc" value="1"<?php if(strpos($this->data->default_order_by, " DESC")!==false) echo " checked"; ?>>
    <span id="tt_sort_desc" class="tooltip"><?=_("Sort column descending.")?></span>
</p>

<div class="toggle">
  <div class="toggle_part toggle_available">
    <div><?=_("Available fields")?>:</div>
    <ul>
<?php
    $propertyCounter = 0;
    foreach (User::getProperties() as $property => $name) {
      if(!in_array($property, $this->data->columns))
        echo "      <li name=\"toggle_{$propertyCounter}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\" disabled>".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\" disabled></li>\n";
      $propertyId[$property] = $propertyCounter++;
    }
    foreach ($bookingProperties as $property => $name) {
      if(!in_array($property, $this->data->columns))
        echo "      <li name=\"toggle_{$propertyCounter}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\" disabled>".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\" disabled></li>\n";
      $propertyId[$property] = $propertyCounter++;
    }
    foreach (UserBookingCheck::getProperties() as $property => $name) {
      if(!in_array($property, $this->data->columns))
        echo "      <li name=\"toggle_{$propertyCounter}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\" disabled>".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\" disabled></li>\n";
      $propertyId[$property] = $propertyCounter++;
    }
    foreach ($pluginColumns as $newColumn) {
      if(!in_array($newColumn['property'], $this->data->columns))
        echo "      <li name=\"toggle_{$propertyCounter}\">{$newColumn['name']}<input type=\"hidden\" name=\"columns[]\" value=\"{$newColumn['property']}\" disabled>".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"{$newColumn['property']}\" disabled></li>\n";
       $propertyId[$newColumn['property']] = $propertyCounter++;
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_add">&raquo;</span><br><span class="toggle_remove">&laquo;</span></div>
  <div class="toggle_part toggle_selected">
    <div><?=_("Selected fields")?>:</div>
    <ul>
<?php
    foreach ($this->data->columns as $property) {
      if($name=User::getProperties($property))
        echo "      <li name=\"toggle_{$propertyId[$property]}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\">".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\"".((in_array($property, $this->data->hidden_columns)) ? " checked" : "")."></li>\n";
      else if($name=UserBookingCheck::getProperties($property))
        echo "      <li name=\"toggle_{$propertyId[$property]}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\">".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\"".((in_array($property, $this->data->hidden_columns)) ? " checked" : "")."></li>\n";
      else if(isset($bookingProperties[$property]) && $name=$bookingProperties[$property])
        echo "      <li name=\"toggle_{$propertyId[$property]}\">{$name}<input type=\"hidden\" name=\"columns[]\" value=\"$property\">".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\"".((in_array($property, $this->data->hidden_columns)) ? " checked" : "")."></li>\n";
      else if($name=array_filter($pluginColumns, function($element) use ($property) { return ($element['property']==$property); })) {
        $name = current($name);
        echo "      <li name=\"toggle_{$propertyId[$property]}\">{$name['name']}<input type=\"hidden\" name=\"columns[]\" value=\"$property\">".
             "<input type=\"checkbox\" name=\"hidden_columns[]\" value=\"$property\"".((in_array($property, $this->data->hidden_columns)) ? " checked" : "")."></li>\n";
      }
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_up">&uArr;</span><br><span class="toggle_down">&dArr;</span></div>
</div>
<span id="tt_hidden_columns" class="tooltip"><?=_("Hide column.")?></span>

<div class="toggle">
  <div class="toggle_part toggle_available">
    <div><?=_("Admins")?>:</div>
    <ul>
<?php
    $adminCounter = 0;
    $admins = array();
    foreach (DbAdmin::readList($DB) as $admin) {
      if(!in_array($admin['id'], $this->data->db_admin_ids))
        echo "      <li name=\"toggle_{$adminCounter}\">{$admin['name']}<input type=\"hidden\" name=\"db_admin_ids[]\" value=\"{$admin['id']}\" disabled></li>\n";
      else 
        $admins[$adminCounter] = $admin;
      $adminCounter++;
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_add">&raquo;</span><br><span class="toggle_remove">&laquo;</span></div>
  <div class="toggle_part toggle_selected toggle_sorted">
    <div><?=_("Selected admins")?>:</div>
    <ul>
<?php
    foreach ($admins as $adminCounter => $admin) {
      echo "      <li name=\"toggle_{$adminCounter}\">{$admin['name']}<input type=\"hidden\" name=\"db_admin_ids[]\" value=\"{$admin['id']}\"></li>\n";
    }
?>
    </ul>
  </div>
  <div class="toggle_control"><span class="toggle_up">&uArr;</span><br><span class="toggle_down">&dArr;</span></div>
</div>

<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_save2" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('ViewUI', 'save'); return false;">
  <input type="submit" id="kdb_save_as2" name="kdb_save_as" value="<?=_("Save as new")?>" onClick="kdbSaveEntry('ViewUI', 'saveasnew'); return false;">
  <input type="submit" id="kdb_delete2" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbDeleteEntry('ViewUI'); return false;">
</p>
</div>
</form>
<?php
  }
}

?>