<?php 
require_once("icwfData.inc.php");
require_once("FormValidation.inc.php");

class EventFee implements icwfData {
  private static $noExport = array();
  private static $notInArray = array("validation", "delete");
  private $validation;
  
  private $event_fee_id;
  private $event_option_id;
  private $event_fee;
  private $deadline;
  
  private $delete;

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  private function initialize() {
    foreach ($this as $key => $value)
      if($key == "fees")
        $this->$key = array();
      else
        $this->$key = null;
  }
  
  public function __construct() {
    $this->initialize();
    
    $this->delete = false;
    
    $this->validation = new FormValidation(array(
        "event_fee"=>array("required"=>true)
      ),
      array(
        "event_fee"=>_("Please enter a fee.")
      ));
  }  

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // get values
  public function __get($name) {
    if($name == "id") $name = "event_fee_id";
    if (array_key_exists($name, get_class_vars(get_class())) && !in_array($name, self::$noExport))
      return $this->$name;
      
    return null;
  }

  public function getIDName() {
    return "event_fee_id";
  }
  
  public function toArray() {
    $array = array();
    foreach ($this as $key => $value)
      if(!in_array($key, self::$notInArray))
        $array[$key] = $value; 
    return $array;
  }
  
  public function getPostBackData() {
    return array($this->getIDName()=>$this->id);
  }

  ////////////////////////////////////////////////////////////////////////////////////////////////
  // set values
  public function setValidation(FormValidation $validation) {
    $this->validation = $validation;
  }
  
  public function deleteFee($delete) {
    $this->delete = ($delete ? 1 : 0);
  }
  
  public function setOptionId($optionId) {
    $this->event_option_id = $optionId;
  }
  
  public function fromArray($array) {
    return true;
  }
  
  public function fromPOSTArray($array, $groupIdx, $optionIdx, $feeIdx) {
    foreach ($this as $key => $value) {
      switch ($key) {
        case "validation":
        case "delete":
          break;
        
        case "event_fee_id":
        case "event_option_id":
          if(isset($array[$key][$groupIdx][$optionIdx][$feeIdx]) && 
             preg_match("~^[0-9]+$~", $array[$key][$groupIdx][$optionIdx][$feeIdx]))
            $this->$key = $array[$key][$groupIdx][$optionIdx][$feeIdx];
          else
            $this->$key = null;
          break;
        case "event_fee":
          if(isset($array[$key][$groupIdx][$optionIdx][$feeIdx]) && 
             preg_match("~^-?[0-9]+$~", $array[$key][$groupIdx][$optionIdx][$feeIdx]))
            $this->$key = $array[$key][$groupIdx][$optionIdx][$feeIdx];
          else
            $this->$key = null;
          break;
        case "deadline":
          if(isset($array[$key][$groupIdx][$optionIdx][$feeIdx]))
            $this->$key = CWFTools::dateLocal2ISO($array[$key][$groupIdx][$optionIdx][$feeIdx], getenv("LC_ALL"));
          else
            $this->$key = null;
          break;
          
        default:
          break;
      }
    }
    return true;
    //return $this->validation->validate($array);
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - read
  public function readData(DbConnection $DB, $conditions) {
    $whereConditions = array();
    foreach ($conditions as $key => $value)
      if(array_key_exists($key, get_class_vars(get_class())))
        $whereConditions[] = "$key=$value";

    $result = $DB->query("SELECT * FROM event_fees WHERE ".implode(" AND ", $whereConditions).";");
    
    if(!$DB->errno() && $DB->num_rows($result)>0) {
      $fee = $DB->fetch_array($result);
      foreach ($fee as $property => $value) {
        if(property_exists($this, $property)) {
          switch ($property) {
            case "deadline":
              if($value!="0000-00-00")
                $this->$property = $value;
              break;
            default:
              $this->$property = $value;
          }
        }
      }
      
      return array(0, "");
    }
    else
      return array($DB->errno(), $DB->error());
  }
  
  static public function readList(DbConnection $DB) {
    return $array;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - write
  public function writeData(DbConnection $DB) {
    if($this->delete)
      return self::deleteData($DB, $this->id);
    else if(isset($this->event_fee_id) && $this->event_fee_id) {
      $result = $DB->query("UPDATE event_fees SET
          event_option_id='{$this->event_option_id}',
          event_fee='{$this->event_fee}',
          deadline='{$this->deadline}'
        WHERE event_fee_id='{$this->event_fee_id}';");
    }
    else {
      $result = $DB->query("INSERT INTO event_fees(
          event_option_id,
          event_fee,
          deadline
        ) VALUES(
          '{$this->event_option_id}',
          '{$this->event_fee}',
          '{$this->deadline}'
        );");
      
      $this->event_fee_id = $DB->insert_id();
    }
    return array($DB->errno(), $DB->error());
  }

  static public function deleteData(DbConnection $DB, $id) {
    if(preg_match("~^[0-9]+$~", $id))
      $condition = "event_fee_id='{$id}'";
    else
      $condition = $id;
      
    $feeIds = $DB->result($DB->query("SELECT group_concat(event_fee_id SEPARATOR ', ') 
                                          FROM event_fees 
                                          WHERE $condition;"), 0, 0);
    $result = $DB->query("DELETE FROM event_fees WHERE {$condition};");
    
    if(!$DB->errno() && $DB->affected_rows()>0) {
      UserBookingOption::deleteData($DB, "event_fee_id IN ({$feeIds})");
      return array(0, "");
    }
    else 
      return array($DB->errno(), $DB->error());
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - misc
  static public function createTable(DbConnection $DB) {
    $result = $DB->query("
      CREATE TABLE event_fees (
        event_fee_id int unsigned NOT NULL AUTO_INCREMENT PRIMARY KEY,
        event_option_id int unsigned,
        event_fee int,
        deadline date,
        INDEX event_option_id (event_option_id)
      );");
    if ($result) { echo _("&nbsp;&nbsp;- creating table").": 'event_fees'.<br>\n"; }
    else { echo _("&nbsp;&nbsp;<b>- Error when creating table</b>")." 'event_fee'<br>\n"; $error = 1; }
  }
}
?>